window.Gleam.initSearch([{"doc":"glistix_nix","title":"glistix_nix","content":"# glistix_nix\n\n**Mirrors:** **[GitHub](https://github.com/glistix/nix)** | **[Codeberg](https://codeberg.org/glistix/nix)**\n\n[![Package Version](https://img.shields.io/hexpm/v/nix_lib)](https://hex.pm/packages/glistix_nix)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glistix_nix/)\n\nA library for interacting with built-in Nix types and functions when using [Glistix](https://github.com/glistix/glistix).\n\n**NOTE:** Functions exposed by this library are only suitable for Glistix&#39;s Nix target,\nand do not work on Erlang or JavaScript, thus [requiring the Glistix compiler](https://github.com/glistix/glistix).\n\n## Installation\n\nRun the command below to use `glistix_nix` in your Glistix project.\n\n```sh\n# Add to your Glistix project\nglistix add glistix_nix\n```\n\nNote that you will have to patch\n`gleam_stdlib` in your project to point to [`glistix/stdlib`](https://github.com/glistix/stdlib).\nSee its README for instructions. (This should be done by default when creating a new Glistix\nproject.)\n\n## Example\n\n```gleam\nimport gleam/io\nimport gleam/int\nimport glistix/nix\nimport glistix/nix/array.{type Array}\nimport glistix/nix/attrset.{type AttrSet}\n\npub fn main() {\n  // Use to deeply evaluate an expression\n  nix.deep_eval(#(io.println(&quot;Hi&quot;)))\n\n  // Work with arrays\n  let array: Array(#(String, Int)) =\n    [1, 2, 3, 4]\n    |&gt; array.from_list\n    |&gt; array.map(fn(x) {\n      let name =\n        x + 1\n        |&gt; int.to_string\n\n      #(name, x)\n    })\n\n  // Work with attribute sets\n  let attrset: AttrSet(Int) =\n    array\n    |&gt; attrset.from_array\n\n  let assert Ok(value) =\n    attrset\n    |&gt; attrset.get(&quot;2&quot;)\n\n  value // -&gt; 1\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glistix_nix&gt;.\n\n## Development\n\nWhen developing, make sure to apply the Glistix patch for `gleam_stdlib`\nlocally so that it may work in the Nix target.\n\nYou can do this by running `git submodule init` to init the\n[`glistix/stdlib`](https://github.com/glistix/stdlib) submodule upon cloning.\n\nYou will then be able to run the command below to the test the library.\n\n```sh\n# Optional: enter a shell with Glistix installed\nnix develop\n# Run library tests\nglistix test\n```\n\n## License\n\nThis project is licensed under Apache 2.0 and MIT, at your option.\n","url":"index.html"},{"doc":"glistix/nix","title":"TypeOf","content":"pub type TypeOf {\n  IntType\n  BoolType\n  StringType\n  PathType\n  NullType\n  SetType\n  ListType\n  LambdaType\n  FloatType\n}\n\nIntType\n\n\nBoolType\n\n\nStringType\n\n\nPathType\n\n\nNullType\n\n\nSetType\n\n\nListType\n\n\nLambdaType\n\n\nFloatType\n\n\nSynonyms:\nglistix/nix.TypeOf\nglistix/nix TypeOf","url":"glistix/nix.html#TypeOf"},{"doc":"glistix/nix","title":"deep_eval","content":"pub fn deep_eval(expression: a) -&gt; a\n Evaluates the expression strictly, recursively.\n\n Nix is lazy by default, so most values aren&#39;t actually computed until\n prompted to by evaluation. This function can be used to force a value\n (one of the parameters) to be recursively evaluated upon evaluation.\n That is, once this function is called, the given value and any values\n within it (such as list items or attribute set values) are also evaluated.\n This is used to ensure side-effects, such as printing (through `trace`)\n or panics, are applied even from within data structures.\n\n Please note that misusing this function may result in performance losses,\n or even infinite recursion with infinite data structures.\n\n ## Examples\n\n \n {\n   deep_eval([panic as &quot;Bad&quot;)])\n   &quot;Unreachable here&quot;\n\n   10\n }\n // -&gt; error: Bad\n \nSynonyms:\nglistix/nix.deep_eval\nglistix/nix deep_eval","url":"glistix/nix.html#deep_eval"},{"doc":"glistix/nix","title":"typeof","content":"pub fn typeof(of subject: a) -&gt; TypeOf\n Gets the Nix type of a value.\n\n Note that this function works with the value&#39;s\n representation within Nix, and so the returned type\n shouldn&#39;t be associated with a particular Gleam type,\n as Gleam types might be represented by different Nix\n types.\nSynonyms:\nglistix/nix.typeof\nglistix/nix typeof","url":"glistix/nix.html#typeof"},{"doc":"glistix/nix","title":"glistix/nix","content":" Library for interacting with Nix built-in types and functions.","url":"glistix/nix.html"},{"doc":"glistix/nix/array","title":"Array","content":"pub type Array(element)\n A Nix list. This is not a linked list, but rather a contiguous array.\n The fastest way to access values in this array is by index.\n Recursion over this type tends to be slower, as a consequence (would be `O(N^2)`).\n\nSynonyms:\nglistix/nix/array.Array\nglistix/nix/array Array","url":"glistix/nix/array.html#Array"},{"doc":"glistix/nix/array","title":"all","content":"pub fn all(\n  in array: Array(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Checks if the predicate is satisfied for all elements in the array,\n returning `True` if the function returns `True` for all elements,\n or `False` if it returned `False` for at least one element.\nSynonyms:\nglistix/nix/array.all\nglistix/nix/array all","url":"glistix/nix/array.html#all"},{"doc":"glistix/nix/array","title":"any","content":"pub fn any(\n  in array: Array(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Checks if the predicate is satisfied for at least one element in the array,\n returning `True` if the function returns `True` for one or more elements,\n or `False` if it returned `False` for all elements.\nSynonyms:\nglistix/nix/array.any\nglistix/nix/array any","url":"glistix/nix/array.html#any"},{"doc":"glistix/nix/array","title":"append","content":"pub fn append(first: Array(a), second: Array(a)) -&gt; Array(a)\n Joins the second array to the end of the first using Nix&#39;s\n built-in `++` operator.\n\n ## Examples\n\n \n append(from_list([1, 2]), from_list([7, 8]))\n // -&gt; from_list([1, 2, 7, 8])\n \nSynonyms:\nglistix/nix/array.append\nglistix/nix/array append","url":"glistix/nix/array.html#append"},{"doc":"glistix/nix/array","title":"concat","content":"pub fn concat(arrays: Array(Array(a))) -&gt; Array(a)\n Concatenates an array of arrays into a single array.\n Uses `builtins.concatLists` for this task.\n\n ## Examples\n\n \n let first = from_list([1, 2])\n let second = from_list([3, 4])\n let third = from_list([5])\n concat(from_list([first, second, third]))\n // -&gt; from_list([1, 2, 3, 4, 5])\n \nSynonyms:\nglistix/nix/array.concat\nglistix/nix/array concat","url":"glistix/nix/array.html#concat"},{"doc":"glistix/nix/array","title":"contains","content":"pub fn contains(array: Array(a), any elem: a) -&gt; Bool\n Checks if an array contains any element equal to the given value.\nSynonyms:\nglistix/nix/array.contains\nglistix/nix/array contains","url":"glistix/nix/array.html#contains"},{"doc":"glistix/nix/array","title":"filter","content":"pub fn filter(\n  array: Array(a),\n  keeping predicate: fn(a) -&gt; Bool,\n) -&gt; Array(a)\n Filters the array, returning a new array containing only the elements\n for which the predicate function returned `True`.\n\n ## Examples\n\n \n filter(from_list([2, 3, 4, 5]), keeping: fn(x) { x &gt; 3 })\n // -&gt; from_list([4, 5])\n\n filter(from_list([2, 3, 4, 5]), keeping: fn(x) { x &lt; 1 })\n // -&gt; from_list([])\n \nSynonyms:\nglistix/nix/array.filter\nglistix/nix/array filter","url":"glistix/nix/array.html#filter"},{"doc":"glistix/nix/array","title":"filter_map","content":"pub fn filter_map(\n  array: Array(a),\n  with operator: fn(a) -&gt; Result(b, c),\n) -&gt; Array(b)\n Filters the array, returning a new array containing only the elements\n for which the given function returned `Ok(new_value)`, replacing each\n with `new_value`.\n\n ## Examples\n\n \n filter_map(\n   from_list([#(1, True), #(2, False), #(3, False), #(4, True)]),\n   with: fn(x) {\n     case x {\n       #(value, True) -&gt; Ok(value)\n       #(_, False) -&gt; Error(Nil)\n     }\n   }\n )\n // -&gt; from_list([1, 4])\n\n filter_map(from_list([2, 3, 4, 5]), with: Error)\n // -&gt; from_list([])\n\n filter_map(from_list([2, 3, 4, 5]), with: fn(x) { Ok(x + 1) })\n // -&gt; from_list([3, 4, 5, 6])\n \nSynonyms:\nglistix/nix/array.filter_map\nglistix/nix/array filter_map","url":"glistix/nix/array.html#filter_map"},{"doc":"glistix/nix/array","title":"find","content":"pub fn find(\n  in array: Array(a),\n  one_that is_desired: fn(a) -&gt; Bool,\n) -&gt; Result(a, Nil)\n Finds the first element in the array for which the function returns `True`.\n\n If no such element exists, returns `Error(Nil)`.\n\n Note that, currently, this will always traverse the whole array.\n\n ## Examples\n\n \n find(from_list([1, 2, 3, 4, 5]), fn(x) { x &gt; 3 })\n // -&gt; Ok(4)\n\n find(from_list([10]), fn(x) { x == 5 })\n // -&gt; Error(Nil)\n \nSynonyms:\nglistix/nix/array.find\nglistix/nix/array find","url":"glistix/nix/array.html#find"},{"doc":"glistix/nix/array","title":"find_map","content":"pub fn find_map(\n  in array: Array(a),\n  with operator: fn(a) -&gt; Result(b, c),\n) -&gt; Result(b, Nil)\n Finds the first element in the array for which the function returns `Ok(new_value)`,\n and then returns `Ok(new_value)`.\n\n If no such element exists (that is, the function returns `Error(_)` for all\n elements in the array, or it is empty), returns `Error(Nil)`.\n\n Note that, currently, this will always traverse the whole array.\n\n ## Examples\n\n \n find_map(\n   from_list([#(1, False), #(2, False), #(3, True), #(4, True)]), fn(x) {\n     case x {\n       #(value, True) -&gt; Ok(value)\n       #(_, False) -&gt; Error(Nil)\n     }\n   })\n )\n // -&gt; Ok(3)\n\n find_map(from_list([from_list([]), from_list([10]), from_list([12, 13])), first)\n // -&gt; Ok(10)\n\n find_map(from_list([from_list([]), from_list([])]), first)\n // -&gt; Error(Nil)\n\n find_map(from_list([]), first)\n // -&gt; Error(Nil)\n \nSynonyms:\nglistix/nix/array.find_map\nglistix/nix/array find_map","url":"glistix/nix/array.html#find_map"},{"doc":"glistix/nix/array","title":"first","content":"pub fn first(array: Array(a)) -&gt; Result(a, Nil)\n Returns the first element of the array, if it isn&#39;t empty.\n\n ## Examples\n\n \n first(from_list([]))\n // -&gt; Error(Nil)\n\n first(from_list([1]))\n // -&gt; Ok(1)\n\n first(from_list([2, 3, 4]))\n // -&gt; Ok(2)\n \nSynonyms:\nglistix/nix/array.first\nglistix/nix/array first","url":"glistix/nix/array.html#first"},{"doc":"glistix/nix/array","title":"flat_map","content":"pub fn flat_map(\n  over array: Array(a),\n  with operator: fn(a) -&gt; Array(b),\n) -&gt; Array(b)\n Similar to `map`, but flattens the resulting array of arrays after mapping.\n\n This function is more efficient than a `map` followed by `flatten`, as it\n uses the built-in `builtins.concatMap` function.\n\n ## Examples\n\n \n flat_map(from_list([8, 9, 10]), fn(x) { from_list([x, x - 1, x * 2]) })\n // -&gt; from_list([8, 7, 16, 9, 8, 18, 10, 9, 20])\n \nSynonyms:\nglistix/nix/array.flat_map\nglistix/nix/array flat_map","url":"glistix/nix/array.html#flat_map"},{"doc":"glistix/nix/array","title":"flatten","content":"pub fn flatten(arrays: Array(Array(a))) -&gt; Array(a)\n This is the same as `concat`, which joins an array of arrays into\n a single array.\n\n ## Examples\n\n \n let first = from_list([1, 2])\n let second = from_list([3, 4])\n let third = from_list([5])\n flatten(from_list([first, second, third]))\n // -&gt; from_list([1, 2, 3, 4, 5])\n \nSynonyms:\nglistix/nix/array.flatten\nglistix/nix/array flatten","url":"glistix/nix/array.html#flatten"},{"doc":"glistix/nix/array","title":"fold","content":"pub fn fold(\n  over array: Array(a),\n  from init: b,\n  with operator: fn(b, a) -&gt; b,\n) -&gt; b\n Reduces a list of elements into a single value by calling a given function\n on each element, going from start to end.\n\n Runs in linear time, and is strict (uses the `foldl&#39;` built-in).\nSynonyms:\nglistix/nix/array.fold\nglistix/nix/array fold","url":"glistix/nix/array.html#fold"},{"doc":"glistix/nix/array","title":"fold_right","content":"pub fn fold_right(\n  over array: Array(a),\n  from init: b,\n  with operator: fn(b, a) -&gt; b,\n) -&gt; b\n Reduces a list of elements into a single value by calling a given function\n on each element, going from end to start.\n\n Runs in linear time, and is lazy and recursive, so large arrays can cause a stack overflow.\nSynonyms:\nglistix/nix/array.fold_right\nglistix/nix/array fold_right","url":"glistix/nix/array.html#fold_right"},{"doc":"glistix/nix/array","title":"from_iterator","content":"pub fn from_iterator(iterator: Iterator(a)) -&gt; Array(a)\n Converts a Gleam iterator to a Nix array.\n\n Runs in linear time.\nSynonyms:\nglistix/nix/array.from_iterator\nglistix/nix/array from_iterator","url":"glistix/nix/array.html#from_iterator"},{"doc":"glistix/nix/array","title":"from_list","content":"pub fn from_list(list: List(a)) -&gt; Array(a)\n Converts a Gleam list to a Nix array.\n\n Runs in linear time, and is recursive, so large lists can cause a stack overflow.\nSynonyms:\nglistix/nix/array.from_list\nglistix/nix/array from_list","url":"glistix/nix/array.html#from_list"},{"doc":"glistix/nix/array","title":"generate","content":"pub fn generate(\n  length: Int,\n  with generator: fn(Int) -&gt; a,\n) -&gt; Array(a)\n Generates an array with a specified length. Takes a function which specifies\n a value for each index in the new array.\n\n Runs in linear time, but is not recursive (uses the built-in `genList` function).\nSynonyms:\nglistix/nix/array.generate\nglistix/nix/array generate","url":"glistix/nix/array.html#generate"},{"doc":"glistix/nix/array","title":"get","content":"pub fn get(array: Array(a), at index: Int) -&gt; Result(a, Nil)\n Get the element at the given index.\n\n ## Examples\n\n \n get(from_list([1, 2, 3]), 0)\n // -&gt; Ok(1)\n\n get(from_list([1, 2, 3]), 2)\n // -&gt; Ok(3)\n\n get(from_list([1, 2, 3]), 3)\n // -&gt; Error(Nil)\n \nSynonyms:\nglistix/nix/array.get\nglistix/nix/array get","url":"glistix/nix/array.html#get"},{"doc":"glistix/nix/array","title":"index_fold","content":"pub fn index_fold(\n  over array: Array(a),\n  from initial: b,\n  with operator: fn(b, a, Int) -&gt; b,\n) -&gt; b\n Similar to `fold`, but the function receives each element&#39;s\n index alongside the accumulator and the element.\n\n Runs in linear time and is strict.\nSynonyms:\nglistix/nix/array.index_fold\nglistix/nix/array index_fold","url":"glistix/nix/array.html#index_fold"},{"doc":"glistix/nix/array","title":"index_map","content":"pub fn index_map(\n  over array: Array(a),\n  with operator: fn(a, Int) -&gt; b,\n) -&gt; Array(b)\n Similar to `map`, but the function receives each element\n as well as its index.\n\n Runs in linear time.\nSynonyms:\nglistix/nix/array.index_map\nglistix/nix/array index_map","url":"glistix/nix/array.html#index_map"},{"doc":"glistix/nix/array","title":"map","content":"pub fn map(\n  over array: Array(a),\n  with operator: fn(a) -&gt; b,\n) -&gt; Array(b)\n Returns a new array containing only the elements of the first array after\n the function has been applied to each one.\n\n Runs in linear time.\nSynonyms:\nglistix/nix/array.map\nglistix/nix/array map","url":"glistix/nix/array.html#map"},{"doc":"glistix/nix/array","title":"new","content":"pub fn new() -&gt; Array(a)\n Creates a new, empty array.\nSynonyms:\nglistix/nix/array.new\nglistix/nix/array new","url":"glistix/nix/array.html#new"},{"doc":"glistix/nix/array","title":"partition","content":"pub fn partition(\n  array: Array(a),\n  with categorise: fn(a) -&gt; Bool,\n) -&gt; #(Array(a), Array(a))\n Partitions an array&#39;s elements into a pair of arrays based on the output\n of the given function. The first array returned includes elements for which\n the function returned `True`, while the second array includes elements for\n which the function returned `False`.\nSynonyms:\nglistix/nix/array.partition\nglistix/nix/array partition","url":"glistix/nix/array.html#partition"},{"doc":"glistix/nix/array","title":"range","content":"pub fn range(from start: Int, to stop: Int) -&gt; Array(Int)\n Creates an array of integers from start to finish, inclusive.\n\n ## Examples\n\n \n range(0, 0)\n // -&gt; from_list([0])\n\n range(0, 5)\n // -&gt; from_list([0, 1, 2, 3, 4, 5])\n\n range(1, -5)\n // -&gt; from_list([1, 0, -1, -2, -3, -4, -5])\n \nSynonyms:\nglistix/nix/array.range\nglistix/nix/array range","url":"glistix/nix/array.html#range"},{"doc":"glistix/nix/array","title":"reduce","content":"pub fn reduce(\n  over array: Array(a),\n  with operator: fn(a, a) -&gt; a,\n) -&gt; Result(a, Nil)\n Similar to `fold`, but the initial value of the accumulator is the first\n element in the array. Returns `Error(Nil)` if the array was empty.\n\n ## Examples\n\n \n reduce(over: from_list([1, 2, 3]), with: fn(a, b) { a + b })\n // -&gt; Ok(6)\n\n reduce(over: from_list([]), with: fn(a, b) { a + b })\n // -&gt; Error(Nil)\n \nSynonyms:\nglistix/nix/array.reduce\nglistix/nix/array reduce","url":"glistix/nix/array.html#reduce"},{"doc":"glistix/nix/array","title":"rest","content":"pub fn rest(array: Array(a)) -&gt; Result(Array(a), Nil)\n Returns the array minus its first element, or `Error(Nil)` if it is empty.\n\n Note that this runs in linear time, so using `rest` with a recursive algorithm\n will yield `O(n^2)` complexity. Consider using increasing indices to access the\n array instead, if possible. Alternatively, use a `List` with such algorithms\n instead, as the equivalent operation over `List` runs in constant time (while\n indexing over a `List` runs in linear time).\n\n ## Examples\n\n \n rest(from_list([]))\n // -&gt; Error(Nil)\n\n rest(from_list([1]))\n // -&gt; Ok(from_list([]))\n\n rest(from_list([1, 2]))\n // -&gt; Ok(from_list([2]))\n \nSynonyms:\nglistix/nix/array.rest\nglistix/nix/array rest","url":"glistix/nix/array.html#rest"},{"doc":"glistix/nix/array","title":"reverse","content":"pub fn reverse(array: Array(a)) -&gt; Array(a)\n Reverses the array, returning a new array with its elements in the opposite\n order as the given array.\n\n Runs in linear time.\n\n ## Examples\n\n \n reverse(from_list([1, 2, 3, 4]))\n // -&gt; from_list([4, 3, 2, 1])\n \nSynonyms:\nglistix/nix/array.reverse\nglistix/nix/array reverse","url":"glistix/nix/array.html#reverse"},{"doc":"glistix/nix/array","title":"single","content":"pub fn single(item: a) -&gt; Array(a)\n Creates an array with one element.\n\n ## Examples\n\n \n single(5)\n // -&gt; from_list([5])\n \nSynonyms:\nglistix/nix/array.single\nglistix/nix/array single","url":"glistix/nix/array.html#single"},{"doc":"glistix/nix/array","title":"size","content":"pub fn size(array: Array(a)) -&gt; Int\n Gets the amount of elements in the array.\n\n Runs in constant time.\nSynonyms:\nglistix/nix/array.size\nglistix/nix/array size","url":"glistix/nix/array.html#size"},{"doc":"glistix/nix/array","title":"sized_chunk","content":"pub fn sized_chunk(\n  in array: Array(a),\n  into count: Int,\n) -&gt; Array(Array(a))\n Splits an array&#39;s elements into chunks of fixed size.\n If the chunk size doesn&#39;t evenly divide the array length,\n the last chunk will be incomplete, containing only the\n remaining elements.\n\n Specifying a chunk size smaller than 1 is the same as\n specifying 1.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4, 5, 6]) |&gt; sized_chunk(into: 2)\n // -&gt; from_list([from_list([1, 2]), from_list([3, 4]), from_list([5, 6])])\n\n from_list([1, 2, 3, 4, 5, 6, 7, 8]) |&gt; sized_chunk(into: 3)\n // -&gt; from_list([from_list([1, 2, 3]), from_list([4, 5, 6]), from_list([7, 8])])\n \nSynonyms:\nglistix/nix/array.sized_chunk\nglistix/nix/array sized_chunk","url":"glistix/nix/array.html#sized_chunk"},{"doc":"glistix/nix/array","title":"slice","content":"pub fn slice(\n  from array: Array(a),\n  at position: Int,\n  take length: Int,\n) -&gt; Result(Array(a), Nil)\n Takes a specific portion of an array, slicing from the given\n position and stopping after the given length, generating a new array.\n Negative lengths can be used to take from the end of the array.\n If the slicing would go out of bounds, returns an error.\n\n ## Examples\n\n \n slice(from: from_list([1, 2, 3, 4]), at: 1, take: 2)\n // -&gt; Ok(from_list([2, 3]))\n\n slice(from: from_list([1, 2, 3, 4]), at: 4, take: -3)\n // -&gt; Ok(from_list([2, 3, 4]))\n\n slice(from: from_list([]), at: 1, take: 2)\n // -&gt; Error(Nil)\n \nSynonyms:\nglistix/nix/array.slice\nglistix/nix/array slice","url":"glistix/nix/array.html#slice"},{"doc":"glistix/nix/array","title":"sort","content":"pub fn sort(\n  array: Array(a),\n  by compare: fn(a, a) -&gt; Order,\n) -&gt; Array(a)\n Sorts an array using the built-in `sort` function through\n the given comparator. Sorts in ascending order by default,\n but the order can be reversed through `order.reverse`\n in the standard library.\n\n This uses a stable sort algorithm, meaning elements which compare equal\n preserve their relative order.\n\n ## Examples\n\n \n sort(from_list([3, 10, 4, 32]), by: int.compare)\n // -&gt; from_list([32, 10, 4, 3])\n\n sort(from_list([3, 10, 4, 32]), by: order.reverse(int.compare))\n // -&gt; from_list([3, 4, 10, 32])\n \nSynonyms:\nglistix/nix/array.sort\nglistix/nix/array sort","url":"glistix/nix/array.html#sort"},{"doc":"glistix/nix/array","title":"split","content":"pub fn split(\n  array: Array(a),\n  at index: Int,\n) -&gt; #(Array(a), Array(a))\n Splits an array in two before the given index.\n If the array isn&#39;t long enough to contain that index,\n the first returned array will be equal to the full given\n array, and the second returned array will be empty.\n\n ## Examples\n\n \n split(from_list([12, 34, 56]), at: 0)\n // -&gt; #(from_list([]), from_list([12, 34, 56]))\n\n split(from_list([12, 34, 56]), at: 1)\n // -&gt; #(from_list([12]), from_list([34, 56]))\n\n split(from_list([12, 34, 56]), at: 3)\n // -&gt; #(from_list([12, 34, 56]), from_list([]))\n \nSynonyms:\nglistix/nix/array.split\nglistix/nix/array split","url":"glistix/nix/array.html#split"},{"doc":"glistix/nix/array","title":"to_iterator","content":"pub fn to_iterator(array: Array(a)) -&gt; Iterator(a)\n Converts a Nix array to a Gleam iterator.\nSynonyms:\nglistix/nix/array.to_iterator\nglistix/nix/array to_iterator","url":"glistix/nix/array.html#to_iterator"},{"doc":"glistix/nix/array","title":"to_list","content":"pub fn to_list(array: Array(a)) -&gt; List(a)\n Converts a Nix array to a Gleam list.\n\n Runs in linear time.\nSynonyms:\nglistix/nix/array.to_list\nglistix/nix/array to_list","url":"glistix/nix/array.html#to_list"},{"doc":"glistix/nix/array","title":"transpose","content":"pub fn transpose(rows: Array(Array(a))) -&gt; Array(Array(a))\n Transpose rows and columns of the array of arrays.\n\n Traverses the array once to determine the amount of columns,\n and then traverses again for each column.\n\n ## Examples\n\n \n transpose(from_list([from_list([1, 2, 3]), from_list([4, 5, 6]), from_list([7, 8, 9])]))\n // -&gt; from_list([from_list([1, 4, 7]), from_list([2, 5, 8]), from_list(3, 6, 9)])\n \nSynonyms:\nglistix/nix/array.transpose\nglistix/nix/array transpose","url":"glistix/nix/array.html#transpose"},{"doc":"glistix/nix/array","title":"unzip","content":"pub fn unzip(input: Array(#(a, b))) -&gt; #(Array(a), Array(b))\n Takes an array of 2-element tuples and returns two arrays.\n\n ## Examples\n\n \n unzip(from_list([#(1, 2), #(3, 4)]))\n // -&gt; #(from_list([1, 3]), from_list([2, 4]))\n\n unzip([])\n // -&gt; #(from_list([]), from_list([]))\n \nSynonyms:\nglistix/nix/array.unzip\nglistix/nix/array unzip","url":"glistix/nix/array.html#unzip"},{"doc":"glistix/nix/array","title":"zip","content":"pub fn zip(\n  first: Array(a),\n  with second: Array(b),\n) -&gt; Array(#(a, b))\n Combines two arrays into an array of 2-element tuples, where the tuple at\n position &#39;i&#39; contains element &#39;i&#39; from the first array and element &#39;i&#39; from\n the second array.\n\n If one array is longer than the other, the returned array will have the\n size of the shortest, with the longer array&#39;s extra items being ignored.\n\n ## Examples\n\n \n zip(from_list([1, 2]), from_list([3, 4]))\n // -&gt; from_list([#(1, 3), #(2, 4)])\n\n zip(from_list([1, 2]), from_list([3]))\n // -&gt; from_list([#(1, 3)])\n\n zip(from_list([1, 2]), from_list([]))\n // -&gt; from_list([])\n \nSynonyms:\nglistix/nix/array.zip\nglistix/nix/array zip","url":"glistix/nix/array.html#zip"},{"doc":"glistix/nix/array","title":"glistix/nix/array","content":" Contains types and functions related to Nix&#39;s built-in lists (consisting of arrays).","url":"glistix/nix/array.html"},{"doc":"glistix/nix/attrset","title":"AttrSet","content":"pub type AttrSet(value)\n Represents any attribute set in Nix, containing values of a single type.\n\nSynonyms:\nglistix/nix/attrset.AttrSet\nglistix/nix/attrset AttrSet","url":"glistix/nix/attrset.html#AttrSet"},{"doc":"glistix/nix/attrset","title":"from_array","content":"pub fn from_array(attrs: Array(#(String, a))) -&gt; AttrSet(a)\n Creates an attribute set from an array of `#(name, value)` pairs.\n\n If there are two attributes with the same name, the first occurrence\n takes precedence.\nSynonyms:\nglistix/nix/attrset.from_array\nglistix/nix/attrset from_array","url":"glistix/nix/attrset.html#from_array"},{"doc":"glistix/nix/attrset","title":"from_dict","content":"pub fn from_dict(dict: Dict(String, a)) -&gt; AttrSet(a)\n Creates an attribute set from a dictionary with string keys.\nSynonyms:\nglistix/nix/attrset.from_dict\nglistix/nix/attrset from_dict","url":"glistix/nix/attrset.html#from_dict"},{"doc":"glistix/nix/attrset","title":"from_list","content":"pub fn from_list(attrs: List(#(String, a))) -&gt; AttrSet(a)\n Creates an attribute set from a list of `#(name, value)` pairs.\n\n If there are two attributes with the same name, the first occurrence\n takes precedence.\nSynonyms:\nglistix/nix/attrset.from_list\nglistix/nix/attrset from_list","url":"glistix/nix/attrset.html#from_list"},{"doc":"glistix/nix/attrset","title":"get","content":"pub fn get(set: AttrSet(a), attr: String) -&gt; Result(a, Nil)\n Gets the value associated with that attribute, if it exists.\nSynonyms:\nglistix/nix/attrset.get\nglistix/nix/attrset get","url":"glistix/nix/attrset.html#get"},{"doc":"glistix/nix/attrset","title":"intersect","content":"pub fn intersect(\n  first: AttrSet(a),\n  with second: AttrSet(b),\n) -&gt; AttrSet(a)\n Generates an attribute set with all attributes in the first set\n which have the same name as some attribute in the second set.\nSynonyms:\nglistix/nix/attrset.intersect\nglistix/nix/attrset intersect","url":"glistix/nix/attrset.html#intersect"},{"doc":"glistix/nix/attrset","title":"map_values","content":"pub fn map_values(\n  in set: AttrSet(a),\n  with fun: fn(String, a) -&gt; b,\n) -&gt; AttrSet(b)\n Updates values in the given attribute set using the output of the given\n function, which is called with each attribute&#39;s name and value and returns\n the new value.\nSynonyms:\nglistix/nix/attrset.map_values\nglistix/nix/attrset map_values","url":"glistix/nix/attrset.html#map_values"},{"doc":"glistix/nix/attrset","title":"merge","content":"pub fn merge(\n  first: AttrSet(a),\n  with second: AttrSet(a),\n) -&gt; AttrSet(a)\n Merges two attribute sets, such that attributes in the second set\n override those in the first with the same name.\nSynonyms:\nglistix/nix/attrset.merge\nglistix/nix/attrset merge","url":"glistix/nix/attrset.html#merge"},{"doc":"glistix/nix/attrset","title":"names","content":"pub fn names(in set: AttrSet(a)) -&gt; Array(String)\n Obtains the list of attribute names in the given attribute set.\n Returns an `Array` as it uses `builtins.attrNames`. You can use\n `array.to_list` to convert to a `List`.\n\n ## Examples\n\n \n from_list([#(&quot;a&quot;, 5), #(&quot;b&quot;, 6)]) |&gt; names\n // -&gt; array.from_list([&quot;a&quot;, &quot;b&quot;])\n \nSynonyms:\nglistix/nix/attrset.names\nglistix/nix/attrset names","url":"glistix/nix/attrset.html#names"},{"doc":"glistix/nix/attrset","title":"new","content":"pub fn new() -&gt; AttrSet(a)\n Creates a new, empty attribute set.\nSynonyms:\nglistix/nix/attrset.new\nglistix/nix/attrset new","url":"glistix/nix/attrset.html#new"},{"doc":"glistix/nix/attrset","title":"set","content":"pub fn set(\n  set: AttrSet(a),\n  at attr: String,\n  to value: a,\n) -&gt; AttrSet(a)\n Updates the value of an attribute in the attribute set,\n returning the new, updated attribute set.\n\n The original attribute set is NOT changed and is immutable.\nSynonyms:\nglistix/nix/attrset.set\nglistix/nix/attrset set","url":"glistix/nix/attrset.html#set"},{"doc":"glistix/nix/attrset","title":"size","content":"pub fn size(set: AttrSet(a)) -&gt; Int\n Gets the amount of attributes in the attribute set.\nSynonyms:\nglistix/nix/attrset.size\nglistix/nix/attrset size","url":"glistix/nix/attrset.html#size"},{"doc":"glistix/nix/attrset","title":"to_array","content":"pub fn to_array(set: AttrSet(a)) -&gt; Array(#(String, a))\n Obtains an array of `#(name, value)` pairs from an attribute set.\nSynonyms:\nglistix/nix/attrset.to_array\nglistix/nix/attrset to_array","url":"glistix/nix/attrset.html#to_array"},{"doc":"glistix/nix/attrset","title":"to_dict","content":"pub fn to_dict(set: AttrSet(a)) -&gt; Dict(String, a)\n Converts an attribute set to a dictionary with string keys.\nSynonyms:\nglistix/nix/attrset.to_dict\nglistix/nix/attrset to_dict","url":"glistix/nix/attrset.html#to_dict"},{"doc":"glistix/nix/attrset","title":"to_list","content":"pub fn to_list(set: AttrSet(a)) -&gt; List(#(String, a))\n Obtains a list of `#(name, value)` pairs from an attribute set.\nSynonyms:\nglistix/nix/attrset.to_list\nglistix/nix/attrset to_list","url":"glistix/nix/attrset.html#to_list"},{"doc":"glistix/nix/attrset","title":"values","content":"pub fn values(in set: AttrSet(a)) -&gt; Array(a)\n Obtains the list of values in the given attribute set.\n Returns an `Array` as it uses `builtins.attrValues`. You can use\n `array.to_list` to convert to a `List`.\n\n ## Examples\n\n \n from_list([#(&quot;a&quot;, 5), #(&quot;b&quot;, 6)]) |&gt; values\n // -&gt; array.from_list([5, 6])\n \nSynonyms:\nglistix/nix/attrset.values\nglistix/nix/attrset values","url":"glistix/nix/attrset.html#values"},{"doc":"glistix/nix/attrset","title":"glistix/nix/attrset","content":" Types and functions related to Nix attribute sets.","url":"glistix/nix/attrset.html"},{"doc":"glistix/nix/path","title":"Path","content":"pub type Path\n Represents a path in the filesystem.\n Usually indicates a file or directory to be saved to the Nix store.\n\nSynonyms:\nglistix/nix/path.Path\nglistix/nix/path Path","url":"glistix/nix/path.html#Path"},{"doc":"glistix/nix/path","title":"from_string","content":"pub fn from_string(string: String) -&gt; Path\n Creates a path from a string.\n When it starts with /, it is absolute (relative to the filesystem root).\n When it starts with ~/, it is relative to the user&#39;s home folder.\n When it starts with ../, it is relative to the parent folder of the current file.\n When it starts with ./ or anything else, it is relative to the folder of the current file.\n\n ## Examples\n\n \n from_string(&quot;./file.nix&quot;)\n // -&gt; //nix(./file.nix)\n \nSynonyms:\nglistix/nix/path.from_string\nglistix/nix/path from_string","url":"glistix/nix/path.html#from_string"},{"doc":"glistix/nix/path","title":"to_string","content":"pub fn to_string(path: Path) -&gt; String\n Converts a path to a string form.\nSynonyms:\nglistix/nix/path.to_string\nglistix/nix/path to_string","url":"glistix/nix/path.html#to_string"},{"doc":"glistix/nix/path","title":"glistix/nix/path","content":" Types and functions related to Nix path types.","url":"glistix/nix/path.html"},{"doc":"glistix/nix/path_like","title":"PathLike","content":"pub type PathLike {\n  NixPath(Path)\n  StringPath(String)\n}\n Represents any object which could be used to represent a path within Nix.\nNixPath(Path)\n A regular path object.\n Usually, when used, triggers a copy to the Nix store.\n\nStringPath(String)\n A string which points to any path in the system.\n\nSynonyms:\nglistix/nix/path_like.PathLike\nglistix/nix/path_like PathLike","url":"glistix/nix/path_like.html#PathLike"},{"doc":"glistix/nix/path_like","title":"glistix/nix/path_like","content":" Module concerning the `PathLike` type.","url":"glistix/nix/path_like.html"},{"doc":"glistix/nix/system","title":"System","content":"pub type System {\n  X8664Linux\n  X8664Darwin\n  Aarch64Linux\n  Aarch64Darwin\n  I686Linux\n  Other(String)\n}\n Represents a possible system (architecture and OS) where Nix is being used.\n Includes most common options, with an additional escape hatch.\nX8664Linux\n\n\nX8664Darwin\n\n\nAarch64Linux\n\n\nAarch64Darwin\n\n\nI686Linux\n\n\nOther(String)\n\n\nSynonyms:\nglistix/nix/system.System\nglistix/nix/system System","url":"glistix/nix/system.html#System"},{"doc":"glistix/nix/system","title":"from_string","content":"pub fn from_string(string: String) -&gt; System\n Parses a `System` from a string.\n\n ## Examples\n\n \n from_string(&quot;x86_64-linux&quot;)\n // -&gt; X8664Linux\n \n\n \n from_string(&quot;aarch64-darwin&quot;)\n // -&gt; Aarch64Darwin\n \n\n \n from_string(&quot;riscv-unknown&quot;)\n // -&gt; Other(&quot;riscv-unknown&quot;)\n \nSynonyms:\nglistix/nix/system.from_string\nglistix/nix/system from_string","url":"glistix/nix/system.html#from_string"},{"doc":"glistix/nix/system","title":"to_string","content":"pub fn to_string(system: System) -&gt; String\n Converts a `System` to its string representation.\n\n ## Examples\n\n \n to_string(X8664Linux)\n // -&gt; &quot;x86_64-linux&quot;\n \n\n \n to_string(Aarch64Darwin)\n // -&gt; &quot;aarch64-darwin&quot;\n \n\n \n to_string(Other(&quot;riscv-unknown&quot;))\n // -&gt; &quot;riscv-unknown&quot;\n \nSynonyms:\nglistix/nix/system.to_string\nglistix/nix/system to_string","url":"glistix/nix/system.html#to_string"},{"doc":"glistix/nix/system","title":"glistix/nix/system","content":"","url":"glistix/nix/system.html"},{"doc":"glistix/nix/derivation","title":"Builder","content":"pub type Builder {\n  Builder(path: PathLike, args: List(String))\n}\n A derivation&#39;s builder program, and the args to call it with.\n Not to be confused with the `DerivationBuilder` type.\nBuilder(path: PathLike, args: List(String))\n\n\nSynonyms:\nglistix/nix/derivation.Builder\nglistix/nix/derivation Builder","url":"glistix/nix/derivation.html#Builder"},{"doc":"glistix/nix/derivation","title":"Derivation","content":"pub type Derivation\n A derivation in Nix is a special attribute set with building information\n as well as where it is to be stored in the Nix store.\n\nSynonyms:\nglistix/nix/derivation.Derivation\nglistix/nix/derivation Derivation","url":"glistix/nix/derivation.html#Derivation"},{"doc":"glistix/nix/derivation","title":"from_attrset","content":"pub fn from_attrset(attrset: AttrSet(a)) -&gt; Derivation\n Converts an attribute set, which is assumed to be a derivation already,\n to a derivation. If it is not a derivation, it will be cast into one\n (that is, it will receive the `type: &quot;derivation&quot;` attribute).\nSynonyms:\nglistix/nix/derivation.from_attrset\nglistix/nix/derivation from_attrset","url":"glistix/nix/derivation.html#from_attrset"},{"doc":"glistix/nix/derivation","title":"new","content":"pub fn new(\n  named name: String,\n  on system: System,\n  using builder: Builder,\n) -&gt; Derivation\n Creates a new derivation.\n Use a `DerivationBuilder` to specify more options.\n\n Please refer to the NixOS manual, at https://nixos.org/manual/nix/stable/language/derivations,\n to learn more about these options.\nSynonyms:\nglistix/nix/derivation.new\nglistix/nix/derivation new","url":"glistix/nix/derivation.html#new"},{"doc":"glistix/nix/derivation","title":"glistix/nix/derivation","content":" Types and functions related to Nix derivations.","url":"glistix/nix/derivation.html"},{"doc":"glistix/nix/derivation_builder","title":"DerivationBuilder","content":"pub opaque type DerivationBuilder(name, system, builder)\n This type lets you compose a derivation&#39;s creation options\n through builder functions.\n\n Use `build` to finish the creation of the derivation.\n\nSynonyms:\nglistix/nix/derivation_builder.DerivationBuilder\nglistix/nix/derivation_builder DerivationBuilder","url":"glistix/nix/derivation_builder.html#DerivationBuilder"},{"doc":"glistix/nix/derivation_builder","title":"build","content":"pub fn build(\n  derivation: DerivationBuilder(String, System, Builder),\n) -&gt; Derivation\n Creates a derivation given its builder.\n The builder must have set a name, system and builder program for the\n derivation.\n Note that this does NOT cause the derivation to be &quot;built&quot; in the Nix sense;\n it simply creates the object representing the derivation.\nSynonyms:\nglistix/nix/derivation_builder.build\nglistix/nix/derivation_builder build","url":"glistix/nix/derivation_builder.html#build"},{"doc":"glistix/nix/derivation_builder","title":"new","content":"pub fn new() -&gt; DerivationBuilder(Nil, Nil, Nil)\n Creates a derivation builder without any initial information.\nSynonyms:\nglistix/nix/derivation_builder.new\nglistix/nix/derivation_builder new","url":"glistix/nix/derivation_builder.html#new"},{"doc":"glistix/nix/derivation_builder","title":"with_builder","content":"pub fn with_builder(\n  derivation: DerivationBuilder(a, b, c),\n  builder: Builder,\n) -&gt; DerivationBuilder(a, b, Builder)\n Sets the program and arguments which will build this derivation.\nSynonyms:\nglistix/nix/derivation_builder.with_builder\nglistix/nix/derivation_builder with_builder","url":"glistix/nix/derivation_builder.html#with_builder"},{"doc":"glistix/nix/derivation_builder","title":"with_extra_option","content":"pub fn with_extra_option(\n  derivation: DerivationBuilder(a, b, c),\n  set name: String,\n  to value: d,\n) -&gt; DerivationBuilder(a, b, c)\n Sets an extra option when creating the derivation.\n Take care here as invalid options will cause a crash.\nSynonyms:\nglistix/nix/derivation_builder.with_extra_option\nglistix/nix/derivation_builder with_extra_option","url":"glistix/nix/derivation_builder.html#with_extra_option"},{"doc":"glistix/nix/derivation_builder","title":"with_name","content":"pub fn with_name(\n  derivation: DerivationBuilder(a, b, c),\n  name: String,\n) -&gt; DerivationBuilder(String, b, c)\n Sets the name of the derivation being built.\nSynonyms:\nglistix/nix/derivation_builder.with_name\nglistix/nix/derivation_builder with_name","url":"glistix/nix/derivation_builder.html#with_name"},{"doc":"glistix/nix/derivation_builder","title":"with_outputs","content":"pub fn with_outputs(\n  derivation: DerivationBuilder(a, b, c),\n  outputs: List(String),\n) -&gt; DerivationBuilder(a, b, c)\n Sets the outputs of this derivation.\n When not specified, the outputs are just `[ &quot;out&quot; ]`.\nSynonyms:\nglistix/nix/derivation_builder.with_outputs\nglistix/nix/derivation_builder with_outputs","url":"glistix/nix/derivation_builder.html#with_outputs"},{"doc":"glistix/nix/derivation_builder","title":"with_system","content":"pub fn with_system(\n  derivation: DerivationBuilder(a, b, c),\n  system: System,\n) -&gt; DerivationBuilder(a, System, c)\n Sets the system of the derivation being built.\nSynonyms:\nglistix/nix/derivation_builder.with_system\nglistix/nix/derivation_builder with_system","url":"glistix/nix/derivation_builder.html#with_system"},{"doc":"glistix/nix/derivation_builder","title":"glistix/nix/derivation_builder","content":" Module for the `DerivationBuilder` type and its functions.","url":"glistix/nix/derivation_builder.html"},{"doc":"glistix/nix/env","title":"current_system","content":"pub fn current_system() -&gt; Result(System, Nil)\n Accesses the current system, if available.\n It won&#39;t be available in pure evaluation mode,\n so it is not recommended to depend on this function.\n\n ## Examples\n\n \n current_system()\n // -&gt; Ok(X8664Linux)\n \nSynonyms:\nglistix/nix/env.current_system\nglistix/nix/env current_system","url":"glistix/nix/env.html#current_system"},{"doc":"glistix/nix/env","title":"current_time","content":"pub fn current_time() -&gt; Result(Int, Nil)\n Accesses the current Unix time in seconds since the epoch\n (January 1, 1970), if available.\n It won&#39;t be available in pure evaluation mode,\n so it is not recommended to depend on this function.\n\n Repeated calls to this function will return the same value as the first.\n\n ## Examples\n\n \n current_time()\n // -&gt; Ok(1683705525)\n \nSynonyms:\nglistix/nix/env.current_time\nglistix/nix/env current_time","url":"glistix/nix/env.html#current_time"},{"doc":"glistix/nix/env","title":"get_env","content":"pub fn get_env(named name: String) -&gt; Result(String, Nil)\n Gets the value of an environment variable at evaluation time,\n if the variable was specified with a non-empty value.\n It is not recommended to depend on this function, in order to\n avoid creating dependencies on the environment.\n\n ## Examples\n\n \n get_env(named: &quot;PATH&quot;)\n // -&gt; Ok(&quot;/usr/bin:/some/folder&quot;)\n\n get_env(named: &quot;VERY_MUCH_UNKNOWN&quot;)\n // -&gt; Error(Nil)\n \nSynonyms:\nglistix/nix/env.get_env\nglistix/nix/env get_env","url":"glistix/nix/env.html#get_env"},{"doc":"glistix/nix/env","title":"glistix/nix/env","content":" Functions to access the outer environment.","url":"glistix/nix/env.html"}]);